@@ -7,10 +7,9 @@
 //! use goose::prelude::*;
 //! ```
 
+pub use crate::config::{GooseDefault, GooseDefaultType};
 pub use crate::goose::{
     GooseTask, GooseTaskError, GooseTaskFunction, GooseTaskResult, GooseTaskSet, GooseUser,
 };
 pub use crate::metrics::{GooseCoordinatedOmissionMitigation, GooseMetrics};
-pub use crate::{
-    task, taskset, GooseAttack, GooseDefault, GooseDefaultType, GooseError, GooseScheduler,
-};
+pub use crate::{task, taskset, GooseAttack, GooseError, GooseScheduler};
