@@ -406,11 +406,13 @@ pub fn error_row(error: &metrics::GooseErrorMetricAggregate) -> String {
 
 /// Build the html report.
 pub fn build_report(
-    start_time: &str,
-    end_time: &str,
-    host: &str,
+    users: &str,
+    report_range: &str,
+    hosts: &str,
     templates: GooseReportTemplates,
 ) -> String {
+    let pkg_name = env!("CARGO_PKG_NAME");
+    let pkg_version = env!("CARGO_PKG_VERSION");
     format!(
         r#"<!DOCTYPE html>
 <html>
@@ -476,8 +478,10 @@ pub fn build_report(
         <h1>Goose Attack Report</h1>
 
         <div class="info">
-            <p>During: <span>{start_time} - {end_time}</span></p>
-            <p>Target Host: <span>{host}</span></p>
+            <p>Users: <span>{users}</span> </p>
+            <p>Target Host: <span>{hosts}</span></p>
+            {report_range}
+            <p><span><small><em>{pkg_name} v{pkg_version}</em></small></span></pr>
         </div>
 
         <div class="requests">
@@ -538,9 +542,11 @@ pub fn build_report(
     </div>
 </body>
 </html>"#,
-        start_time = start_time,
-        end_time = end_time,
-        host = host,
+        users = users,
+        report_range = report_range,
+        hosts = hosts,
+        pkg_name = pkg_name,
+        pkg_version = pkg_version,
         raw_requests_template = templates.raw_requests_template,
         raw_responses_template = templates.raw_responses_template,
         co_requests_template = templates.co_requests_template,
