@@ -23,15 +23,15 @@ const USERS: usize = 5;
 const RUN_TIME: usize = 2;
 
 // Test task.
-pub async fn login(user: &GooseUser) -> GooseTaskResult {
-    let request_builder = user.goose_post(LOGIN_PATH).await?;
+pub async fn login(user: &mut GooseUser) -> GooseTaskResult {
+    let request_builder = user.goose_post(LOGIN_PATH)?;
     let params = [("username", "me"), ("password", "s3crET!")];
     let _goose = user.goose_send(request_builder.form(&params), None).await?;
     Ok(())
 }
 
 // Test task.
-pub async fn logout(user: &GooseUser) -> GooseTaskResult {
+pub async fn logout(user: &mut GooseUser) -> GooseTaskResult {
     let _goose = user.get(LOGOUT_PATH).await?;
     Ok(())
 }
@@ -108,7 +108,7 @@ fn get_tasks() -> GooseTaskSet {
 
 // Helper to run the test, takes a flag for indicating if running in standalone
 // mode or Gaggle mode.
-fn run_load_test(is_gaggle: bool) {
+async fn run_load_test(is_gaggle: bool) {
     // Start the mock server.
     let server = MockServer::start();
 
@@ -125,17 +125,17 @@ fn run_load_test(is_gaggle: bool) {
             common::run_load_test(
                 common::build_load_test(configuration, &get_tasks(), None, None),
                 None,
-            );
+            )
+            .await;
         }
         true => {
             // Build common configuration.
             let worker_configuration = common_build_configuration(&server, Some(true), None);
 
             // Workers launched in own threads, store thread handles.
-            let worker_handles = common::launch_gaggle_workers(
-                common::build_load_test(worker_configuration, &get_tasks(), None, None),
-                EXPECT_WORKERS,
-            );
+            let worker_handles = common::launch_gaggle_workers(EXPECT_WORKERS, || {
+                common::build_load_test(worker_configuration.clone(), &get_tasks(), None, None)
+            });
 
             // Build Manager configuration.
             let manager_configuration =
@@ -145,7 +145,8 @@ fn run_load_test(is_gaggle: bool) {
             common::run_load_test(
                 common::build_load_test(manager_configuration, &get_tasks(), None, None),
                 Some(worker_handles),
-            );
+            )
+            .await;
         }
     }
 
@@ -153,17 +154,17 @@ fn run_load_test(is_gaggle: bool) {
     validate_test(&mock_endpoints);
 }
 
-#[test]
+#[tokio::test]
 // Test taskset with only on_start() and on_stop() tasks.
-fn test_no_normal_tasks() {
+async fn test_no_normal_tasks() {
     // Run load test with is_gaggle set to false.
-    run_load_test(false);
+    run_load_test(false).await;
 }
 
-#[test]
+#[tokio::test(flavor = "multi_thread", worker_threads = 8)]
 #[cfg_attr(not(feature = "gaggle"), ignore)]
 // Test taskset with only on_start() and on_stop() tasks, in Gaggle mode.
-fn test_no_normal_tasks_gaggle() {
+async fn test_no_normal_tasks_gaggle() {
     // Run load test with is_gaggle set to true.
-    run_load_test(true);
+    run_load_test(true).await;
 }
